@@ -1,6 +1,6 @@
 package HTML::Entities;
 
-# $Id: Entities.pm,v 1.24 2003/01/18 12:32:04 gisle Exp $
+# $Id: Entities.pm,v 1.25 2003/01/19 04:12:43 gisle Exp $
 
 =head1 NAME
 
@@ -57,8 +57,8 @@ This routine is exported by default.
 
 This routine works just like encode_entities, except that the replacement
 entities are always C<&#xI<hexnum>;> and never C<&I<entname>;>.  For
-example, C<escape_entities("r\Xf4le")> returns "r&ocirc;le", but
-C<escape_entities_numeric("r\Xf4le")> returns "r&#xF4;le".
+example, C<escape_entities("r\xF4le")> returns "r&ocirc;le", but
+C<escape_entities_numeric("r\xF4le")> returns "r&#xF4;le".
 
 This routine is I<not> exported by default.  But you can always
 export it with C<use HTML::Entities qw(encode_entities_numeric);>
@@ -102,7 +102,7 @@ require Exporter;
 @EXPORT = qw(encode_entities decode_entities _decode_entities);
 @EXPORT_OK = qw(%entity2char %char2entity encode_entities_numeric);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.24 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.25 $ =~ /(\d+)\.(\d+)/);
 sub Version { $VERSION; }
 
 require HTML::Parser;  # for fast XS implemented decode_entities
